==> helper-maven-plugin-1.5-sources.jar: org/nuiton/io/rest/RequestFactory.java <==
package org.nuiton.io.rest;
/*
 * #%L
 * Helper Maven Plugin
 * $Id: RequestFactory.java 854 2012-07-15 20:54:45Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/maven-helper-plugin/tags/maven-helper-plugin-1.5/src/main/java/org/nuiton/io/rest/RequestFactory.java $
 * %%
 * Copyright (C) 2009 - 2012 Tony Chemit, CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import java.text.DateFormat;
import java.text.SimpleDateFormat;

/**
 * Factory of {@link RestRequest}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.5
 */
public interface RequestFactory {

    public static final DateFormat DATE_FORMAT =
            new SimpleDateFormat("yyyy-MM-dd");

    void addDefaultRequests();

    /**
     * Add a request into the factory.
     *
     * @param builder the new request to add
     */
    void addRequestBuilder(RestRequestBuilder builder);

    /**
     * Obtain a request given his id and the args given.
     *
     * @param id   id of the request
     * @param args args passed to build the request
     * @return the new request
     */
    RestRequest getRequest(String id, Object... args);

    /**
     * Obtain the request builder from a given request id.
     *
     * @param id the id of request to seek for
     * @return the requets builder or {@code null} if not found
     */
    RestRequestBuilder getRequestBuilder(String id);
}

==> helper-maven-plugin-1.6-sources.jar: org/nuiton/io/rest/RequestFactory.java <==
package org.nuiton.io.rest;
/*
 * #%L
 * Helper Maven Plugin
 * $Id: RequestFactory.java 867 2012-10-25 06:45:19Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/maven-helper-plugin/tags/maven-helper-plugin-1.6/src/main/java/org/nuiton/io/rest/RequestFactory.java $
 * %%
 * Copyright (C) 2009 - 2012 Tony Chemit, CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import java.text.DateFormat;
import java.text.SimpleDateFormat;

/**
 * Factory of {@link RestRequest}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.5
 * @deprecated since 1.6, see http://nuiton.org/issues/2355, will be removed and not replaced in version 2.0
 */
@Deprecated
public interface RequestFactory {

    public static final DateFormat DATE_FORMAT =
            new SimpleDateFormat("yyyy-MM-dd");

    void addDefaultRequests();

    /**
     * Add a request into the factory.
     *
     * @param builder the new request to add
     */
    void addRequestBuilder(RestRequestBuilder builder);

    /**
     * Obtain a request given his id and the args given.
     *
     * @param id   id of the request
     * @param args args passed to build the request
     * @return the new request
     */
    RestRequest getRequest(String id, Object... args);

    /**
     * Obtain the request builder from a given request id.
     *
     * @param id the id of request to seek for
     * @return the requets builder or {@code null} if not found
     */
    RestRequestBuilder getRequestBuilder(String id);
}
